<?php

// $Id: input_formats.admin.inc,v 1.3 2010/06/16 15:48:37 dagmar Exp $

/**
 * @file
 * Admin page callbacks for the input formats module.
 */

require_once ( dirname(__FILE__) . '/input_formats.api.inc');

function theme_input_formats_filter_admin_overview($form) {
  $rows = array();
  foreach ($form as $name => $element) {
    if (isset($element['roles']) && is_array($element['roles'])) {
      $rows[] = array(
        drupal_render($form['default'][$element['id']['#value']]),
        check_plain($name),
        drupal_render($element['roles']),
        drupal_render($element['configure']),
        drupal_render($element['export']),
        drupal_render($element['delete'])
      );
      unset($form[$name]);
    }
  }
  $header = array(t('Default'), t('Name'), t('Roles'), array('data' => t('Operations'), 'colspan' => 3));
  $output = theme('table', $header, $rows);
  $output .= drupal_render($form);

  return $output;
}

function input_formats_admin_export_page($format) {
  drupal_set_title(t("Export %format", array('%format' => $format->name)));
  return drupal_get_form('input_formats_admin_export', $format);
}

function input_formats_admin_export(&$form_state, $format) {

  $input_format_name = input_formats_api_get_machine_name($format->format);
  $input_format = input_formats_api_load($input_format_name);
  $export = input_formats_api_export($input_format);

  $form['export'] = array(
    '#type' => 'textarea',
    '#title' => t('Exported code'),
    '#default_value' => $export,
    '#rows' => 20,
  );

  return $form;
}

function input_formats_admin_import() {
  $form['machine_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Machine name'),
    '#description' => t('Optional. Use this machine name instead the provided in the import code.'),
  );
  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#description' => t('Optional. Use this name instead the provided in the import code.'),
  );
  $form['import'] = array(
    '#type' => 'textarea',
    '#title' => t('Import code'),
    '#rows' => 10,
    '#description' => t('Paste here the code to import. If Name and Machine Name are provided, they will be used overriting values pasted here'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Import'),
  );

  return $form;
}


function input_formats_admin_import_validate($form, &$form_state) {
  // Re-use validations checks
  input_formats_update_filter_validate($form, $form_state);
  input_formats_api_check_human_name($form_state['values']['name']);
}

/**
 * Submit function triggered when a input format is imported.
 */
function input_formats_admin_import_submit($form, $form_state) {
  $code = '$input_format = ' . $form_state['values']['import'];
  @eval($code);

  // Preliminary error trapping, must have valid arrays to work with.
  if (!isset($input_format) || !input_formats_api_check_integrity($input_format)) {
    drupal_set_message(t('An error has occured and the input format could not be imported.'), 'error');
    return;
  }
  if (!empty($form_state['values']['machine_name'])) {
    $input_format['machine_name'] = $form_state['values']['machine_name'];
  }
  if (!empty($form_state['values']['name'])) {
    $input_format['name'] = $form_state['values']['name'];
  }
  input_formats_api_save($input_format);
}

/**
 * Menu callback; confirm revert of an input format.
 */
function input_formats_admin_revert() {
  $format = arg(4);
  $format = db_fetch_object(db_query('SELECT * FROM {filter_formats} WHERE format = %d', $format));

  if ($format) {
    if ($format->format != variable_get('filter_default_format', 1)) {
      $form['format'] = array('#type' => 'hidden', '#value' => $format->format);
      $form['name'] = array('#type' => 'hidden', '#value' => $format->name);

      return confirm_form($form, t('Are you sure you want to revert the input format %format?', array('%format' => $format->name)), 'admin/settings/filters', t('All the settings for this Input Format will be deleted and restored from code.'), t('Revert'), t('Cancel'));
    }
    else {
      drupal_set_message(t('The default format cannot be reverted.'));
      drupal_goto('admin/settings/filters');
    }
  }
  else {
    drupal_not_found();
  }
}

/**
 * Process filter delete form submission.
 */
function input_formats_admin_revert_submit($form, &$form_state) {
  $format = $form_state['values']['format'];
  $machine_name = input_formats_api_get_machine_name($format);
  $input_format = input_formats_api_load_from_code($machine_name);

  input_formats_api_revert($input_format);

  drupal_set_message(t('Reverted settings for Input format %format.', array('%format' => $form_state['values']['name'])));

  $form_state['redirect'] = 'admin/settings/filters';
  return;
}
